@@ -121,7 +121,10 @@ enum RedKey {
     REDKEY_ESCAPE_BASE = 0x100,
     REDKEY_PAD_ENTER = REDKEY_ESCAPE_BASE + 0x1c,
     REDKEY_R_CTRL = REDKEY_ESCAPE_BASE + 0x1d,
+    REDKEY_MUTE = REDKEY_ESCAPE_BASE + 0x20,
     REDKEY_FAKE_L_SHIFT = REDKEY_ESCAPE_BASE + 0x2a,
+    REDKEY_VOLUME_DOWN = REDKEY_ESCAPE_BASE + 0x2e,
+    REDKEY_VOLUME_UP = REDKEY_ESCAPE_BASE + 0x30,
     REDKEY_PAD_DIVIDE = REDKEY_ESCAPE_BASE + 0x35,
     REDKEY_FAKE_R_SHIFT = REDKEY_ESCAPE_BASE + 0x36,
     REDKEY_CTRL_PRINT_SCREEN = REDKEY_ESCAPE_BASE + 0x37,
