@@ -22,7 +22,7 @@
 #include "canvas.h"
 #define SPICE_CANVAS_INTERNAL
 #define SW_CANVAS_CACHE
-#include "sw_canvas.h"
+#include "common/sw_canvas.h"
 #undef SW_CANVAS_CACHE
 #undef SPICE_CANVAS_INTERNAL
 
@@ -45,8 +45,6 @@ public:
 
 private:
     RedPixmap *_pixmap;
-    unsigned long _base;
-    unsigned long _max;
 };
 
 #endif
